
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#pragma once

#include <glib-object.h>


#if defined (GTK_SOURCE_COMPILATION) && defined (HAVE_CONFIG_H)
# include <config.h>
#endif

#if !defined (GTK_SOURCE_H_INSIDE) && !defined (GTK_SOURCE_COMPILATION)
# error "Only <gtksourceview/gtksource.h> can be included directly."
#endif

#include <gtksourceview/gtksourceversion.h>


G_BEGIN_DECLS

/* enumerations from "gtksourcebuffer.h" */

GTK_SOURCE_ENUM_EXTERN
GType gtk_source_bracket_match_type_get_type (void);
#define GTK_SOURCE_TYPE_BRACKET_MATCH_TYPE (gtk_source_bracket_match_type_get_type())

GTK_SOURCE_ENUM_EXTERN
GType gtk_source_change_case_type_get_type (void);
#define GTK_SOURCE_TYPE_CHANGE_CASE_TYPE (gtk_source_change_case_type_get_type())

GTK_SOURCE_ENUM_EXTERN
GType gtk_source_sort_flags_get_type (void);
#define GTK_SOURCE_TYPE_SORT_FLAGS (gtk_source_sort_flags_get_type())

/* enumerations from "gtksourcecompletion.h" */

GTK_SOURCE_ENUM_EXTERN
GType gtk_source_completion_error_get_type (void);
#define GTK_SOURCE_TYPE_COMPLETION_ERROR (gtk_source_completion_error_get_type())

/* enumerations from "gtksourcecompletioncontext.h" */

GTK_SOURCE_ENUM_EXTERN
GType gtk_source_completion_activation_get_type (void);
#define GTK_SOURCE_TYPE_COMPLETION_ACTIVATION (gtk_source_completion_activation_get_type())

/* enumerations from "gtksourcefile.h" */

GTK_SOURCE_ENUM_EXTERN
GType gtk_source_newline_type_get_type (void);
#define GTK_SOURCE_TYPE_NEWLINE_TYPE (gtk_source_newline_type_get_type())

GTK_SOURCE_ENUM_EXTERN
GType gtk_source_compression_type_get_type (void);
#define GTK_SOURCE_TYPE_COMPRESSION_TYPE (gtk_source_compression_type_get_type())

/* enumerations from "gtksourcefileloader.h" */

GTK_SOURCE_ENUM_EXTERN
GType gtk_source_file_loader_error_get_type (void);
#define GTK_SOURCE_TYPE_FILE_LOADER_ERROR (gtk_source_file_loader_error_get_type())

/* enumerations from "gtksourcefilesaver.h" */

GTK_SOURCE_ENUM_EXTERN
GType gtk_source_file_saver_error_get_type (void);
#define GTK_SOURCE_TYPE_FILE_SAVER_ERROR (gtk_source_file_saver_error_get_type())

GTK_SOURCE_ENUM_EXTERN
GType gtk_source_file_saver_flags_get_type (void);
#define GTK_SOURCE_TYPE_FILE_SAVER_FLAGS (gtk_source_file_saver_flags_get_type())

/* enumerations from "gtksourcegutterrenderer.h" */

GTK_SOURCE_ENUM_EXTERN
GType gtk_source_gutter_renderer_state_get_type (void);
#define GTK_SOURCE_TYPE_GUTTER_RENDERER_STATE (gtk_source_gutter_renderer_state_get_type())

GTK_SOURCE_ENUM_EXTERN
GType gtk_source_gutter_renderer_alignment_mode_get_type (void);
#define GTK_SOURCE_TYPE_GUTTER_RENDERER_ALIGNMENT_MODE (gtk_source_gutter_renderer_alignment_mode_get_type())

/* enumerations from "gtksourcespacedrawer.h" */

GTK_SOURCE_ENUM_EXTERN
GType gtk_source_space_type_flags_get_type (void);
#define GTK_SOURCE_TYPE_SPACE_TYPE_FLAGS (gtk_source_space_type_flags_get_type())

GTK_SOURCE_ENUM_EXTERN
GType gtk_source_space_location_flags_get_type (void);
#define GTK_SOURCE_TYPE_SPACE_LOCATION_FLAGS (gtk_source_space_location_flags_get_type())

/* enumerations from "gtksourceview.h" */

GTK_SOURCE_ENUM_EXTERN
GType gtk_source_view_gutter_position_get_type (void);
#define GTK_SOURCE_TYPE_VIEW_GUTTER_POSITION (gtk_source_view_gutter_position_get_type())

GTK_SOURCE_ENUM_EXTERN
GType gtk_source_smart_home_end_type_get_type (void);
#define GTK_SOURCE_TYPE_SMART_HOME_END_TYPE (gtk_source_smart_home_end_type_get_type())

GTK_SOURCE_ENUM_EXTERN
GType gtk_source_background_pattern_type_get_type (void);
#define GTK_SOURCE_TYPE_BACKGROUND_PATTERN_TYPE (gtk_source_background_pattern_type_get_type())

G_END_DECLS

/* Generated data ends here */

